==> foundation-ui-components-1.8.1.tgz: package/src/common/card/NsIconText.tsx <==
import Box from '@mui/material/Box';
import { AdditionalProps } from '../common.types';
import { styled } from '@nuskin/foundation-theme';

type NsIconTextProps = {
    text: string;
    body: string;
} & AdditionalProps;

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        width: '222px',
        backgroundColor: '#F5F5F5',
        padding: '20px',
        justifyContent: 'center',
        gap: '30px',
        '.icon': {
            display: 'flex',
            width: '100%',
        },
        '.divider': {
            width: '182px',
            height: '1px',
            background: '#B2B2B2',
        },
        '.title': {
            fontSize: '26px',
            fontWeight: 400,
            marginTop: '-10px',
        },
        '.text': {
            fontWeight: 400,
            fontSize: '14px',
        },
    };
});

const NsIconText = ({ text, body, additionalProps }: NsIconTextProps) => {
    return (
        <CardContainer data-testid={additionalProps?.testid}>
            <div className="icon">
                <svg xmlns="http://www.w3.org/2000/svg" width="80" height="80" viewBox="0 0 80 80" fill="none">
                    <path
                        d="M40 80C62.0914 80 80 62.0914 80 40C80 17.9086 62.0914 0 40 0C17.9086 0 0 17.9086 0 40C0 62.0914 17.9086 80 40 80Z"
                        fill="white"
                    />
                    <path
                        opacity="0.3"
                        d="M43.7138 75.6844C62.5411 73.4233 73.528 54.1872 57.8386 44.0119C46.8517 37.2284 19.7234 38.6174 17.646 51.4899C15.0035 67.8672 29.589 77.9456 43.7138 75.6844Z"
                        fill="#F56767"
                    />
                    <path
                        d="M2.66699 40.4277H77.5603"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M16 60H64"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                        stroke-dasharray="5 5"
                    />
                    <path
                        d="M25.333 69.334L54.6663 69.334"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                        stroke-dasharray="7 7"
                    />
                    <path
                        d="M8 48.9556C9.73125 51.1044 23.5567 54.3276 41.6428 49.4257C58.2309 44.9938 70.7303 46.8336 73.3333 48.5258"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M24 22.668V25.3346"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M24 33.334V36.0007"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M50.6665 12V14.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M50.6665 22.666V25.3327"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M17.3335 29.332H20.0002"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M28 29.332H30.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M44 18.668H46.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M54.6665 18.668H57.3332"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                </svg>
            </div>
            <article className="title">{text}</article>
            <div className="divider"></div>
            <article className="text">{body}</article>
        </CardContainer>
    );
};
export default NsIconText;

==> foundation-ui-components-1.11.0.tgz: package/src/common/card/NsIconText.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

type NsIconTextProps = {
    text: string;
    body: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        width: '222px',
        backgroundColor: '#F5F5F5',
        padding: '20px',
        justifyContent: 'center',
        gap: '30px',
        '.icon': {
            display: 'flex',
            width: '100%',
        },
        '.divider': {
            width: '182px',
            height: '1px',
            background: '#B2B2B2',
        },
        '.title': {
            fontSize: '26px',
            fontWeight: 400,
            marginTop: '-10px',
        },
        '.text': {
            fontWeight: 400,
            fontSize: '14px',
        },
    };
});

const NsIconText = ({ text, body, className }: NsIconTextProps) => {
    return (
        <CardContainer className={className} data-testid="icon-text-card">
            <div className="icon">
                <svg xmlns="http://www.w3.org/2000/svg" width="80" height="80" viewBox="0 0 80 80" fill="none">
                    <path
                        d="M40 80C62.0914 80 80 62.0914 80 40C80 17.9086 62.0914 0 40 0C17.9086 0 0 17.9086 0 40C0 62.0914 17.9086 80 40 80Z"
                        fill="white"
                    />
                    <path
                        opacity="0.3"
                        d="M43.7138 75.6844C62.5411 73.4233 73.528 54.1872 57.8386 44.0119C46.8517 37.2284 19.7234 38.6174 17.646 51.4899C15.0035 67.8672 29.589 77.9456 43.7138 75.6844Z"
                        fill="#F56767"
                    />
                    <path
                        d="M2.66699 40.4277H77.5603"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M16 60H64"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                        stroke-dasharray="5 5"
                    />
                    <path
                        d="M25.333 69.334L54.6663 69.334"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                        stroke-dasharray="7 7"
                    />
                    <path
                        d="M8 48.9556C9.73125 51.1044 23.5567 54.3276 41.6428 49.4257C58.2309 44.9938 70.7303 46.8336 73.3333 48.5258"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M24 22.668V25.3346"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M24 33.334V36.0007"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M50.6665 12V14.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M50.6665 22.666V25.3327"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M17.3335 29.332H20.0002"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M28 29.332H30.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M44 18.668H46.6667"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                    <path
                        d="M54.6665 18.668H57.3332"
                        stroke="#252525"
                        stroke-width="2"
                        stroke-linecap="round"
                        stroke-linejoin="round"
                    />
                </svg>
            </div>
            <article className="title">{text}</article>
            <div className="divider"></div>
            <article className="text">{body}</article>
        </CardContainer>
    );
};
export default NsIconText;
